==> gax-0.5.0-sources.jar: com/google/api/gax/grpc/PagedListDescriptor.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.grpc;

/**
 * An interface which describes the paging pattern.
 *
 * <p>
 * This is public only for technical reasons, for advanced usage.
 */
public interface PagedListDescriptor<RequestT, ResponseT, ResourceT> {

  /**
   * Delivers the empty page token.
   */
  Object emptyToken();

  /**
   * Injects a page token into the request.
   */
  RequestT injectToken(RequestT payload, Object token);

  /**
   * Injects page size setting into the request.
   */
  RequestT injectPageSize(RequestT payload, int pageSize);

  /*
   * Extracts the page size setting from the request.
   */
  Integer extractPageSize(RequestT payload);

  /**
   * Extracts the next token from the response. Returns the empty token if there are no more pages.
   */
  Object extractNextToken(ResponseT payload);

  /**
   * Extracts an iterable of resources from the response.
   */
  Iterable<ResourceT> extractResources(ResponseT payload);
}

==> gax-0.9.0-sources.jar: com/google/api/gax/grpc/PagedListDescriptor.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.google.api.gax.grpc;

/**
 * An interface which describes the paging pattern.
 *
 * <p>
 * This is public only for technical reasons, for advanced usage.
 */
public interface PagedListDescriptor<RequestT, ResponseT, ResourceT> {

  /**
   * Delivers the empty page token.
   */
  String emptyToken();

  /**
   * Injects a page token into the request.
   */
  RequestT injectToken(RequestT payload, String token);

  /**
   * Injects page size setting into the request.
   */
  RequestT injectPageSize(RequestT payload, int pageSize);

  /**
   * Extracts the page size setting from the request.
   */
  Integer extractPageSize(RequestT payload);

  /**
   * Extracts the next token from the response. Returns the empty token if there are no more pages.
   */
  String extractNextToken(ResponseT payload);

  /**
   * Extracts an iterable of resources from the response.
   */
  Iterable<ResourceT> extractResources(ResponseT payload);
}
